@@ -7,8 +7,10 @@ import functools
 import subprocess
 import contextlib
 import logging
+
 try:
     from pathlib import Path as PathlibPath
+
     PathlibPath().expanduser()  # not existing in python2 version of pathlib
 except (ImportError, AttributeError):
     from pathlib2 import Path as PathlibPath
@@ -30,6 +32,7 @@ def resolve(path, *joins):
     Returns:
         path with resolved ~, symbolic links and relative paths.
         *joins: parts to join with path
+
     Examples:
         Resolves relative paths
         >>> import os
@@ -53,10 +56,10 @@ def resolve(path, *joins):
     # make it absolute
     path = os.path.abspath(path)
     # resolve symlinks but preserve '//' in the beginning
-    is_nas_path = path.startswith('//')
+    is_nas_path = path.startswith("//")
     path = os.path.realpath(path)
     if is_nas_path:
-        path = '/' + path
+        path = "/" + path
 
     return path
 
@@ -69,15 +72,15 @@ def cp(source, dest, overwrite=True):
     dest = resolve(dest)
     if os.path.isfile(dest):
         if not overwrite:
-            raise ValueError("Attempt to overwrite destination path"
-                             " {0}.".format(dest))
+            raise ValueError(
+                "Attempt to overwrite destination path" " {0}.".format(dest)
+            )
     if os.path.isfile(source):
         shutil.copy(source, dest)
     elif os.path.isdir(source):
         shutil.copytree(source, dest)
     else:
-        raise TypeError("Source {source} is not file or dir"
-                        .format(**locals()))
+        raise TypeError("Source {source} is not file or dir".format(**locals()))
 
 
 def scp(source, dest):
@@ -86,7 +89,7 @@ def scp(source, dest):
     """
     # subprocess.check_call does not execute in bash, so it does not know ~
     # Carefull when giving remote host : ~ replacement is not tested
-    subprocess.check_call(['scp', source, dest])
+    subprocess.check_call(["scp", source, dest])
 
 
 def mv(source, dest, overwrite=True):
@@ -97,8 +100,10 @@ def mv(source, dest, overwrite=True):
     dest = resolve(dest)
     log = logging.getLogger()
     if os.path.isfile(dest) and not overwrite:
-        raise ValueError("Attempting to move to already existing destination"
-                         " path {0}.".format(dest))
+        raise ValueError(
+            "Attempting to move to already existing destination"
+            " path {0}.".format(dest)
+        )
     log.info("Moving file or dir {0} to {1}".format(source, dest))
     if os.path.isfile(source):
         shutil.move(source, dest)
@@ -169,7 +174,7 @@ def mkdir(path, isDir=False):
         directory = path
     else:
         directory = os.path.dirname(path)
-    if not os.path.exists(directory) and not directory == '':
+    if not os.path.exists(directory) and not directory == "":
         log.info("Create directory {0}".format(directory))
         os.makedirs(directory)
     else:
