@@ -29,8 +29,8 @@ Examples:
     Plot a colorbar
     >>> cbar = rna.plotting.set_colorbar(axes, artist)
 
-    Show the app and start the loop
-    >>> rna.plotting.show()
+    Show the app and start the loop. Commented for doctests
+    # >>> rna.plotting.show()
 
     Switching back to default
     >>> rna.plotting.use('matplotlib')
